==> jmb.tools-0.7.tar.gz: jmb.tools-0.7/jmb/tools/port/buildout2.py <==
import io
import re
import os
import shutil
import click
import six
import subprocess
from collections import OrderedDict
from jmb.tools.utils.functions import execute

SKELETON_DIR = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'skel')

@click.command('b2')
@click.option('--app', '-a', is_flag=True, default=False, help="Is an app")
@click.option('--go', '-g', is_flag=True, default=False, help="Go on with jmb-go -BdD")
@click.option('--keep-vpython', '-k', is_flag=True, default=False, help="Keep vpython inplace")
@click.option('-2', 'py_version', flag_value=2, default=True, help="Run jmb-go with opt -2 (py2)")
@click.option('-3', 'py_version', flag_value=3, help="Run jmb-go with opt -3 (py3)")
def migrate_to_buildout2(app, go, keep_vpython, py_version):
    "Migrate conf of this buildout to buildout2"
    if not os.path.exists('thunder-buildout.cfg'):
        click.echo(click.style("Missing thunder-buildout.cfg, quitting", fg='red', bold=True))
    extra = app and '-japp' or ''
    shutil.copy(os.path.join(SKELETON_DIR, 'bootstrap.py'), '.')
    shutil.copy(os.path.join(SKELETON_DIR, 'thunder-buildout{}.cfg'.format(extra)), 'thunder-buildout.cfg')
    fix_buildout_cfg(extra)
    add_versions_cfg()
    if os.path.exists('parts/vpython') and not keep_vpython:
        dest = '/tmp/vpython-{}'.format(os.path.basename(os.getcwd()))
        shutil.rmtree(dest, ignore_errors=True)
        shutil.move('parts/vpython', dest)
    # jmb go
    go_cmd = 'jmb-go -{}BdD'.format(py_version)
    click.echo(click.style(go_cmd, fg='red'))
    if go:
        subprocess.call(go_cmd.split())
    # Missing hgignore
    # Missing uno path

def fix_buildout_cfg(extra):
    cp = six.moves.configparser.ConfigParser()
    cp.read('buildout.cfg')
    sections_old = read_ini('buildout.cfg')
    sections_new = read_ini(os.path.join(SKELETON_DIR, 'buildout{}.cfg'.format(extra)))
    sections_new['sources'] = sections_old['sources']
    sections_new['versions'] += sections_old['versions']
    new_content = "\n".join(content for content in sections_new.values())
    new_content = new_content.replace('jmb_python_module', cp.get('django','project'))
    new_content = new_content.replace('jmb-default-pkg', cp.get('buildout','project-name'))
    if 'setuptools' in new_content:
        new_content = re.sub('^.*setuptools.*$', '', new_content, flags=re.MULTILINE)

    with io.open('buildout.cfg', 'w') as f:
        f.write(new_content)
    return

def read_ini(filename):
    sections = OrderedDict()
    current_section = ''
    with io.open(filename) as f:
        content = f.read()
    for line in content.split('\n'):
        m = re.match('\[(?P<section>\w+)\]', line)
        if m:
            current_section = m.group('section')
            sections[current_section] = [line]
        elif current_section:
            sections[current_section] += [line]
    for section in sections:
        sections[section] = "\n".join(sections[section])

    return sections

def add_versions_cfg():
    with io.open('versions.cfg', 'w') as f:
        f.write(u'[versions]\n')
        subprocess.call('hg add versions.cfg'.split())
    ret_code, out, err = execute("jmb-test-setup")
    with io.open('versions.cfg', 'a') as f:
        for line in out.splitlines():
            if re.search('setuptools|djangorecipe', line):
                continue
            m = re.search('/(?P<name>\w+)-(?P<version>[\d\.\w]+)-py.*.egg', line)
            if m:
                new_line = u"{name} = {version}".format(**m.groupdict())
                f.write(new_line + u"\n")

    return

==> jmb.tools-0.7.1.tar.gz: jmb.tools-0.7.1/jmb/tools/port/buildout2.py <==
import io
import re
import os
import shutil
import click
import six
import subprocess
from collections import OrderedDict
from jmb.tools.utils.functions import execute

SKELETON_DIR = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'skel')


@click.command('b2')
@click.option('--app', '-a', is_flag=True, default=False, help="Is an app")
@click.option('--go', '-g', is_flag=True, default=False, help="Go on with jmb-go -BdD")
@click.option('--keep-vpython', '-k', is_flag=True, default=False, help="Keep vpython inplace")
@click.option('-2', 'py_version', flag_value=2, default=True, help="Run jmb-go with opt -2 (py2)")
@click.option('-3', 'py_version', flag_value=3, help="Run jmb-go with opt -3 (py3)")
def migrate_to_buildout2(app, go, keep_vpython, py_version):
    "Migrate conf of this buildout to buildout2"
    if not os.path.exists('thunder-buildout.cfg'):
        click.echo(click.style("Missing thunder-buildout.cfg, quitting", fg='red', bold=True))
    extra = app and '-japp' or ''
    shutil.copy(os.path.join(SKELETON_DIR, 'bootstrap.py'), '.')
    shutil.copy(
        os.path.join(SKELETON_DIR,
                     'thunder-buildout{}.cfg'.format(extra)),
     'thunder-buildout.cfg')
    fix_buildout_cfg(extra)
    add_versions_cfg()
    if os.path.exists('parts/vpython') and not keep_vpython:
        dest = '/tmp/vpython-{}'.format(os.path.basename(os.getcwd()))
        shutil.rmtree(dest, ignore_errors=True)
        shutil.move('parts/vpython', dest)
    # jmb go
    go_cmd = 'jmb-go -{}BdD'.format(py_version)
    click.echo(click.style(go_cmd, fg='red'))
    if go:
        subprocess.call(go_cmd.split())
    # Missing hgignore
    # Missing uno path


def fix_buildout_cfg(extra):
    cp = six.moves.configparser.ConfigParser()
    cp.read('buildout.cfg')
    sections_old = read_ini('buildout.cfg')
    sections_new = read_ini(os.path.join(SKELETON_DIR, 'buildout{}.cfg'.format(extra)))
    sections_new['sources'] = sections_old['sources']
    sections_new['versions'] += sections_old['versions']
    new_content = "\n".join(content for content in sections_new.values())
    new_content = new_content.replace('jmb_python_module', cp.get('django', 'project'))
    new_content = new_content.replace('jmb-default-pkg', cp.get('buildout', 'project-name'))
    if 'setuptools' in new_content:
        new_content = re.sub('^.*setuptools.*$', '', new_content, flags=re.MULTILINE)

    with io.open('buildout.cfg', 'w') as f:
        f.write(new_content)
    return


def read_ini(filename):
    sections = OrderedDict()
    current_section = ''
    with io.open(filename) as f:
        content = f.read()
    for line in content.split('\n'):
        m = re.match('\[(?P<section>\w+)\]', line)
        if m:
            current_section = m.group('section')
            sections[current_section] = [line]
        elif current_section:
            sections[current_section] += [line]
    for section in sections:
        sections[section] = "\n".join(sections[section])

    return sections


def add_versions_cfg():
    with io.open('versions.cfg', 'w') as f:
        f.write(u'[versions]\n')
        subprocess.call('hg add versions.cfg'.split())
    ret_code, out, err = execute("jmb-test-setup")
    with io.open('versions.cfg', 'a') as f:
        for line in out.splitlines():
            if re.search('setuptools|djangorecipe', line):
                continue
            m = re.search('/(?P<name>\w+)-(?P<version>[\d\.\w]+)-py.*.egg', line)
            if m:
                new_line = u"{name} = {version}".format(**m.groupdict())
                f.write(new_line + u"\n")

    return
